@@ -2,19 +2,29 @@ from __future__ import annotations
 
 import functools
 import itertools
+from collections.abc import Sequence
+from typing import overload
 
 from musictool.chord import SpecificChord
 from musictool.note import SpecificNote
 from musictool.util.cache import Cached
 
 
-class Progression(Cached):
+class Progression(Cached, Sequence[SpecificChord]):
     def __init__(self, chords: tuple[SpecificChord, ...], /):
-        self.chords = chords
         if not all(isinstance(x, SpecificChord) for x in chords):
             raise TypeError('only SpecificChord items allowed')
+        self.chords = chords
 
-    def __getitem__(self, item: int) -> SpecificChord:
+    @overload
+    def __getitem__(self, i: int) -> SpecificChord: ...
+
+    @overload
+    def __getitem__(self, s: slice) -> Progression: ...
+
+    def __getitem__(self, item: int | slice) -> SpecificChord | Sequence[SpecificChord]:
+        if isinstance(item, slice):
+            return Progression(self.chords[item])
         return self.chords[item]
 
     def __iter__(self):
@@ -24,7 +34,12 @@ class Progression(Cached):
         return len(self.chords)
 
     def __repr__(self):
-        return f'Progression{self.chords})'
+        return f'Progression{self.chords}'
+
+    def __eq__(self, other):
+        return self.chords == other.chords
+
+    def __hash__(self): return hash(self.chords)
 
     def all(self, checks__):
         return all(check(a, b) for a, b in itertools.pairwise(self) for check in checks__)
@@ -52,3 +67,6 @@ class Progression(Cached):
     @functools.cached_property
     def transposed_to_C0(self) -> Progression:
         return self + (SpecificNote('C', 0) - self[0][0])
+
+    def __getnewargs__(self):
+        return self.chords,
